@@ -1,9 +1,9 @@
 package Tapper::TAP::Harness;
-# git description: v5.0.4-1-g4074665
+# git description: v5.0.5-2-gc7bd02c
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Tapper specific TAP handling
-$Tapper::TAP::Harness::VERSION = '5.0.5';
+$Tapper::TAP::Harness::VERSION = '5.0.6';
 use 5.010;
 use strict;
 use warnings;
@@ -53,7 +53,7 @@ our @SECTION_HEADER_KEYS_GENERAL = qw(ram cpuinfo bios lspci lsusb uname osname
                                       simnow-device-interface-version
                                       simnow-bsd-file
                                       simnow-image-file
-                                      ticket-url wiki-url planning-id moreinfo-url
+                                      ticket-url wiki-url planning-id moreinfo-url codereview-url
                                       tags
                                     );
 
@@ -419,14 +419,12 @@ sub _aggregate_sections
         }
         $aggregator->stop;
 
-        # exit
         foreach (qw(total
                     passed
                     parse_errors
                     skipped
                     todo
                     todo_passed
-                    wait
                     failed
                     todo_passed
                   ))
